# Gartner® TIME Framework
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/time#overview)
  * [TIME Classification](https://help.sap.com/docs/leanix/ea/time#time-classification)
  * [Implementing the Gartner® TIME Framework in SAP LeanIX](https://help.sap.com/docs/leanix/ea/time#implementing-the-gartner%C2%AE-time-framework-in-sap-leanix)
  * [Configuring the TIME Classification Attribute for Fact Sheets](https://help.sap.com/docs/leanix/ea/time#configuring-the-time-classification-attribute-for-fact-sheets)
  * [Applying the TIME Classification](https://help.sap.com/docs/leanix/ea/time#applying-the-time-classification)
  * [Using the TIME Classification for Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/time#using-the-time-classification-for-application-portfolio-assessment)
